# Copyright (C) 2020 by Vd.
# This file is part of BetterLogging, my logging improvement.
# BetterLogging is released under the MIT License (see LICENSE).


colors = dict(
    c_reset="\x1b[0m",
    c_bright="\x1b[1m",
    c_dim="\x1b[2m",
    c_underscore="\x1b[4m",
    c_blink="\x1b[5m",
    c_reverse="\x1b[7m",
    c_hidden="\x1b[8m",

    c_fg_black="\x1b[30m",
    c_fg_red="\x1b[31m",
    c_fg_green="\x1b[32m",
    c_fg_yellow="\x1b[33m",
    c_fg_blue="\x1b[34m",
    c_fg_magenta="\x1b[35m",
    c_fg_cyan="\x1b[36m",
    c_fg_white="\x1b[37m",
    c_fg_crimson="\x1b[38m",

    c_bg_black="\x1b[40m",
    c_bg_red="\x1b[41m",
    c_bg_green="\x1b[42m",
    c_bg_yellow="\x1b[43m",
    c_bg_blue="\x1b[44m",
    c_bg_magenta="\x1b[45m",
    c_bg_cyan="\x1b[46m",
    c_bg_white="\x1b[47m",
    c_bg_crimson="\x1b[48m",
)
